@@ -16,12 +16,16 @@ plot.mm.s <- function(s, whichcells=NULL,
                       label.cells = FALSE,
                       use.names=TRUE,
                       show.bursts = FALSE,
-                      main=NULL, ylab='spikes of cell',
+                      main=NULL, ylab='Channel',
+                      xlab="Time (s)",
                       for.figure=FALSE,
                       ...) {
   ## Plot the spikes.
-  ## WHICHCELLS is a list of cell numbers to plot; the default is to plot
-  ## all of the cells.
+  ##
+  ## WHICHCELLS is a list of cell numbers to plot; the default is to
+  ## plot all of the cells.  If NA is given instead of a channel
+  ## reference, just add some whitespace rather than a spike train.
+  ##
   ## BEG and END are the time range for which we want to
   ## plot spikes.  When evaluating maxtime, some cells may have no
   ## spikes; their lists get converted to NA in unlist() so those NA
@@ -69,7 +73,7 @@ plot.mm.s <- function(s, whichcells=NULL,
   } else {
     plot( c(beg, end), c(0,1), type='n', bty='n',
          yaxt="n", main=main,
-         xlab="time (s)", ylab=ylab, ...)
+         xlab=xlab, ylab=ylab, ...)
   }
   
   ymin <- 0
@@ -80,7 +84,8 @@ plot.mm.s <- function(s, whichcells=NULL,
     n <- length(ts)                     #number of spikes.
 
     if(n > 0) {
-      ## check we have spikes; e.g. cell could be NA
+      ## check we have spikes; e.g. cell could be NA, so we wouldn't
+      ## need to do anything except clear a bit of space.
       ys <- numeric(n) + ymin
       
       segments(ts, ys, ts, ys+deltay, lwd=0.2) #draw spikes.
@@ -201,7 +206,7 @@ read.spikes <- function(reader, ...) {
   ## so that e.g.
   ## jay.read.spikes(...) can be called as:
   ## read.spikes(..., reader="jay")
-  readers <- c("feller", "iit", "litke", "ncl", "sanger", "sun", "jay")
+  readers <- c("feller", "iit", "litke", "ncl", "sanger", "sun", "jay", "sql")
   if (reader %in% readers) {
     fn <- paste(reader, ".read.spikes", sep="")
     do.call(fn, list(...))
